summaryrefslogtreecommitdiffstats
path: root/intl/locale/tests/LangPackMatcherTestUtils.sys.mjs
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-05-15 03:34:42 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-05-15 03:34:42 +0000
commitda4c7e7ed675c3bf405668739c3012d140856109 (patch)
treecdd868dba063fecba609a1d819de271f0d51b23e /intl/locale/tests/LangPackMatcherTestUtils.sys.mjs
parentAdding upstream version 125.0.3. (diff)
downloadfirefox-da4c7e7ed675c3bf405668739c3012d140856109.tar.xz
firefox-da4c7e7ed675c3bf405668739c3012d140856109.zip
Adding upstream version 126.0.upstream/126.0
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'intl/locale/tests/LangPackMatcherTestUtils.sys.mjs')
-rw-r--r--intl/locale/tests/LangPackMatcherTestUtils.sys.mjs4
1 files changed, 2 insertions, 2 deletions
diff --git a/intl/locale/tests/LangPackMatcherTestUtils.sys.mjs b/intl/locale/tests/LangPackMatcherTestUtils.sys.mjs
index 4b18f1be13..e746d558bd 100644
--- a/intl/locale/tests/LangPackMatcherTestUtils.sys.mjs
+++ b/intl/locale/tests/LangPackMatcherTestUtils.sys.mjs
@@ -5,7 +5,7 @@
import { LangPackMatcher } from "resource://gre/modules/LangPackMatcher.sys.mjs";
/**
* LangPackMatcher.jsm calls out to to the addons store, which involves network requests.
* Other tests create a fake addons server, and install mock XPIs. At the time of this
* writing that infrastructure is not available for mochitests.
*
@@ -26,7 +26,7 @@ import { LangPackMatcher } from "resource://gre/modules/LangPackMatcher.sys.mjs"
export function getAddonAndLocalAPIsMocker(testScope, sandbox) {
const { info } = testScope;
return function mockAddonAndLocaleAPIs({ systemLocale, appLocale }) {
- info("Mocking LangPackMatcher.jsm APIs");
+ info("Mocking LangPackMatcher.sys.mjs APIs");
let resolveLangPacks;
const langPackPromise = new Promise(resolve => {
@@ -5,7 +5,7 @@
import { LangPackMatcher } from "resource://gre/modules/LangPackMatcher.sys.mjs";
/**
- * LangPackMatcher.jsm calls out to to the addons store, which involves network requests.
+ * LangPackMatcher.sys.mjs calls out to to the addons store, which involves network requests.
* Other tests create a fake addons server, and install mock XPIs. At the time of this
* writing that infrastructure is not available for mochitests.